/* Creating SalesOrder Table for X12 850 */

CREATE TABLE salesorder (
    SalesOrderID NUMBER NOT NULL,
    TxnSetPurpose varchar2(45),
    POType varchar2(45),
    PONumber varchar2(45),
    ReleaseNumber varchar2(45),
    PODate DATE, 
    ContractNumber varchar2(45),
    ArrivalCode varchar2(45),
    DepartmentNumber varchar2(45),
    InternalVendorNumber varchar2(45),
    PromotionalDealNumber varchar2(45),
    RefDescription varchar2(80),
    DeliveryContactName varchar2(60),
    GuestEmail varchar2(80),
    GuestFax varchar2(80),
    GuestTelephone varchar2(80),
    ShipPaymentMethod varchar2(45),
    ShipLocationType varchar2(45),
    ShipLocationDescription varchar2(80),
    SalesRequirement varchar2(45),
    SACIndicator varchar2(45),
    SACAgency varchar2(80),
    SACType varchar2(45),
    TermsType varchar2(45),
    TermsBasisDateType varchar2(45),
    TermsDiscountPercent varchar2(45),
    TermsDiscountDueDate DATE,
    TermsDiscountDaysDue NUMBER,
    TermsDueDate DATE,
    TermsNetDays NUMBER,
    TermsDescription varchar2(80),
    TermsDayofMonth varchar2(45),
    PaymentMethod varchar2(45),
    PromotionStartDate DATE,
    ShipNotBeforeDate DATE,
    ShipNoLaterDate DATE,
    NoDeliveryAfterDate DATE,
    NoDeliveryBeforeDate DATE,
    PromisedDeliveryDate DATE,
    RequestedPickupDate DATE,
    RoutingSeq varchar2(45),
    SCAC varchar2(80),
    BuyerAssignedText varchar2(80),
    TransportationMethod varchar2(80),
    TruckLoadRounding varchar2(45),
    OrderInstructions varchar2(80),
    BuyerName varchar2(60),
    BuyerIdCode varchar2(80),
    BuyerAddress varchar2(55),
    BuyerCity varchar2(45),
    BuyerState varchar2(45),
    BuyerZip varchar2(45),
    BuyerCountryCode varchar2(45),
    FactoryName varchar2(60),
    FactoryIdCode varchar2(80),
    FactoryAddress varchar2(55),
    FactoryCity varchar2(45),
    FactoryState varchar2(45),
    FactoryZip varchar2(45),
    FactoryCountryCode varchar2(45),
    ShipToName varchar2(60),
    ShipToIdCode varchar2(80),
    ShipToAddress varchar2(80),
    ShipToCity varchar2(45),
    ShipToState varchar2(45),
    ShipToZip varchar2(45),
    ShipToCountryCode varchar2(45),
    NumberofLineItems NUMBER,
    HashTotal NUMBER,
    CONSTRAINT salesorder_pk PRIMARY KEY (SalesOrderID)
);
CREATE SEQUENCE seq_SalesOrderID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_SalesOrderID
    BEFORE INSERT ON salesorder
    FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.SalesOrderID IS NULL OR :NEW.SalesOrderID = 0) THEN
   SELECT seq_SalesOrderID.NEXTVAL INTO :NEW.SalesOrderID FROM SYS.DUAL;
  END IF;
END TRI_SalesOrderID;

/* Creating SalesOrderLineItem Table for X12 850 */

CREATE TABLE salesorderlineitem (
  SOLineItemId NUMBER NOT NULL,
  SalesOrderID NUMBER NOT NULL,
  LineNumber varchar2(45),
  QuantityOrdered NUMBER,
  BasisForMeasurement varchar2(45),
  UnitPrice varchar2(45),
  BasisOfUnitPrice varchar2(45),
  BuyerCatalogNumber varchar2(50),
  EAN varchar2(50),
  EAN_UCC varchar2(50),
  BuyerItemNumber varchar2(50),
  UPCCode varchar2(50),
  VendorStyleNumber varchar2(50),
  ClassTrade varchar2(45),
  ResaleUnitPrice varchar2(45),
  UnitCostPrice varchar2(45),
  MultiplePriceQuantity varchar2(45),
  ItemDescriptionType varchar2(45),
  ProductCharacteristic varchar2(45),
  AgencyQualifier varchar2(45),
  ProductDescription varchar2(80),
  NumberOfPacks NUMBER,
  NumberOfInnerPacks NUMBER,
  SACIndicator varchar2(45),
  SACAgency varchar2(45),
  SACType varchar2(45),
  SACTicketingCode varchar2(45),
  SalesRequirements varchar2(45),
  CONSTRAINT salesorderlineitem_pk PRIMARY KEY (SOLineItemID)
);

CREATE SEQUENCE seq_SOLineItemID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_SOLineItemID
  BEFORE INSERT ON salesorderlineitem
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.SOLineItemID IS NULL OR :NEW.SOLineItemID = 0) THEN
   SELECT seq_SOLineItemID.NEXTVAL INTO :NEW.SOLineItemID FROM SYS.DUAL;
  END IF;
END TRI_SOLineItemID;

/* Creating Invoice Table for X12 810 */

CREATE TABLE invoice (
  InvoiceID NUMBER NOT NULL,
  InvoiceDate DATE,
  InvoiceNumber varchar2(45),
  TransactionType varchar2(45),
  NoteReference varchar2(45),
  NoteDescription varchar2(45),
  CurrencyCode varchar2(45),
  DraftNumber varchar2(45),
  InvoiceIdentification varchar2(45),
  InternalVendorNumber varchar2(45),
  LetterOfCreditNumber varchar2(45),
  BrokerRefNumber varchar2(45),
  RefDescription varchar2(45),
  TermsType varchar2(45),
  TermsBasisDateType varchar2(45),
  TermsDueDate DATE,
  TermsNetDays NUMBER,
  DeliveryDate DATE,
  PresentmentDate DATE,
  DocumentReceivedDate DATE,
  ReportType varchar2(45),
  ReportActions varchar2(45),
  ReportActionType varchar2(45),
  VesselName varchar2(45),
  CountryCode varchar2(45),
  TransportationMethod varchar2(45),
  DraftAmount NUMBER(8,2),
  TotalInvoiceAmount NUMBER(8,2),
  CreditOrDebitFlag varchar2(45),
  CartonsShipped NUMBER,
  CONSTRAINT invoice_pk PRIMARY KEY (InvoiceID)
);

CREATE SEQUENCE seq_InvoiceID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_InvoiceID
  BEFORE INSERT ON invoice
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.InvoiceID IS NULL OR :NEW.InvoiceID = 0) THEN
   SELECT seq_InvoiceID.NEXTVAL INTO :NEW.InvoiceID FROM SYS.DUAL;
  END IF;
END TRI_InvoiceID;

/* Creating InvoiceLineItem Table for X12 810 */

CREATE TABLE invoicelineitem (
  InvoiceLineItemID NUMBER NOT NULL,
  InvoiceID NUMBER NOT NULL,
  QuantityInvoiced NUMBER,
  UnitPrice NUMBER(10,2),
  BuyerCatalogNumber varchar2(50),
  EAN varchar2(50),
  EAN_UCC varchar2(50),
  UPCCode varchar2(50),
  ProductDescription varchar2(80),
  PONumber varchar2(45),
  SACIndicator varchar2(45),
  SACType varchar2(45),
  SACAmount varchar2(45),
  SACTicketingServiceQuantity NUMBER,
  SACHangerServiceQuantity NUMBER,
  ManufacturerName varchar2(60),
  ManufactuereCountryCode varchar2(45),
  CONSTRAINT invoicelineitem_pk PRIMARY KEY (InvoiceLineItemID)
);

CREATE SEQUENCE seq_InvoiceLineItemID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_InvoiceLineItemID
  BEFORE INSERT ON invoicelineitem
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.InvoiceLineItemID IS NULL OR :NEW.InvoiceLineItemID = 0) THEN
   SELECT seq_InvoiceLineItemID.NEXTVAL INTO :NEW.InvoiceLineItemID FROM SYS.DUAL;
  END IF;
END TRI_InvoiceLineItemID;

/* Creating ASNShipment Table for X12 856*/

CREATE TABLE asnshipment (
  ASNShipmentID NUMBER NOT NULL,
  TxnSetPurpose varchar2(45),
  ShipmentID varchar2(45),
  ShipmentTxnCreationDate DATE,
  HierarchicalStructure varchar2(45),
  HLID varchar2(45),
  HLParentID varchar2(45),
  CarrierRoutingSeq varchar2(45),
  SCAC varchar2(45),
  TransportationMethod varchar2(45),
  BOLNumber varchar2(45),
  ShippedDate varchar2(45),
  ShipToIdCode varchar2(45),
  CONSTRAINT asnshipment_pk PRIMARY KEY (ASNShipmentID)
);

CREATE SEQUENCE seq_ASNShipmentID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_ASNShipmentID
  BEFORE INSERT ON asnshipment
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.ASNShipmentID IS NULL OR :NEW.ASNShipmentID = 0) THEN
   SELECT seq_ASNShipmentID.NEXTVAL INTO :NEW.ASNShipmentID FROM SYS.DUAL;
  END IF;
END TRI_ASNShipmentID;

/* Creating ASNOrder Table for X12 856 */

CREATE TABLE asnorder (
  ASNOrderID NUMBER NOT NULL,
  ASNShipmentID NUMBER NOT NULL,
  HLID varchar2(45),
  HLParentID varchar2(45),
  PONumber varchar2(45),
  PackagingType varchar2(45),
  LadingQuantity varchar2(45),
  CONSTRAINT asnorder_pk PRIMARY KEY (ASNOrderID)
);

CREATE SEQUENCE seq_ASNOrderID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_ASNOrderID
  BEFORE INSERT ON asnorder
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.ASNOrderID IS NULL OR :NEW.ASNOrderID = 0) THEN
   SELECT seq_ASNOrderID.NEXTVAL INTO :NEW.ASNOrderID FROM SYS.DUAL;
  END IF;
END TRI_ASNOrderID;

/* Creating ASNTare Table for X12 856 */

CREATE TABLE asntare (
  ASNTareID NUMBER NOT NULL,
  ASNOrderID NUMBER NOT NULL,
  HLID varchar2(45),
  HLParentID varchar2(45),
  SSCC18 varchar2(45),
  SSCC18_AppID varchar2(45),
  CONSTRAINT asntare_pk PRIMARY KEY (ASNTareID)
);

CREATE SEQUENCE seq_ASNTareID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_ASNTareID
  BEFORE INSERT ON asntare
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.ASNTareID IS NULL OR :NEW.ASNTareID = 0) THEN
   SELECT seq_ASNTareID.NEXTVAL INTO :NEW.ASNTareID FROM SYS.DUAL;
  END IF;
END TRI_ASNTareID;

/* Creating ASNPack Table for X12 856 */

CREATE TABLE asnpack (
  ASNPackID NUMBER NOT NULL,
  ASNTareID NUMBER NOT NULL,
  HLID varchar2(45),
  HLParentID varchar2(45),
  SSCC18 varchar2(45),
  SSCC18_AppID varchar2(45),
  EAN varchar2(45),
  FirstCartonBarcode varchar2(45),
  LastCartonBarcode varchar2(45),
  GTIN14 varchar2(45),
  GTIN12_13 varchar2(45),
  CONSTRAINT asnpack_pk PRIMARY KEY (ASNPackID)
);

CREATE SEQUENCE seq_ASNPackID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_ASNPackID
  BEFORE INSERT ON asnpack
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.ASNPackID IS NULL OR :NEW.ASNPackID = 0) THEN
   SELECT seq_ASNPackID.NEXTVAL INTO :NEW.ASNPackID FROM SYS.DUAL;
  END IF;
END TRI_ASNPackID;

/* Creating ASNItem Table for X12 856 */

CREATE TABLE asnitem (
  ASNItemID NUMBER NOT NULL,
  ASNPackID NUMBER NOT NULL,
  HLID varchar2(45),
  HLParentID varchar2(45),
  BuyerCatalogNumber varchar2(45),
  EAN varchar2(45),
  UPCConsumerPackageCode varchar2(45),
  VendorStyleNumber varchar2(45),
  ShippedUnits varchar2(45),
  BasisforMeasurement varchar2(45),
  NumberOfPacks varchar2(45),
  NumberOfInnerPacks varchar2(45),
  CONSTRAINT asnitem_pk PRIMARY KEY (ASNItemID)
);

CREATE SEQUENCE seq_ASNItemID START WITH 1 INCREMENT BY 1;

CREATE TRIGGER TRI_ASNItemID
  BEFORE INSERT ON asnitem
  FOR EACH ROW
BEGIN
  IF INSERTING AND (:NEW.ASNItemID IS NULL OR :NEW.ASNItemID = 0) THEN
   SELECT seq_ASNItemID.NEXTVAL INTO :NEW.ASNItemID FROM SYS.DUAL;
  END IF;
END TRI_ASNItemID;